<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapMiddleManual</name>
    <message>
        <location filename="../SnapMiddleManualInit.js" line="+2"/>
        <source>&amp;Middle Manual</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt c&amp;entralny ręcznie</translation>
    </message>
</context>
</TS>
